ewa.ply.lex.Lexer

Package ewa :: Package ply :: Module lex :: Class Lexer |
[hide private]
[frames] | no frames]

# Class Lexer

source code

Instance Methods | [hide private]
__init__(self) | source code
clone(self, object=None) | source code
writetab(self, tabfile, outputdir=`'````'`) | source code
readtab(self, tabfile, fdict) | source code
input(self, s) | source code
begin(self, state) | source code
push_state(self, state) | source code
pop_state(self) | source code
current_state(self) | source code
skip(self, n) | source code
token(self) | source code
__iter__(self) | source code
next(self) | source code
__next__(self) | source code